#ifndef GM_H_INCLUDED
#define GM_H_INCLUDED

#ifdef BUILD_DLL
#define DLL_EXPORT __declspec(dllexport)
#else
#define DLL_EXPORT __declspec(dllimport)
#endif

///Libraries
//SDL libraries
#include <SDL/SDL.h>
#include <SDL/SDL_image.h>///must be installed and configured
#include <SDL/SDL_ttf.h>///must be installed and configured
#include <SDL/SDL_getenv.h>//included with SDL headers by default
//standart C libraries
#include <stdlib.h>
#include <stdio.h>
#include <windows.h>
#include <unistd.h>
//GMLib libraries
#include "GM_Structures.h"


#define TTF_FILE "cour.ttf"//ttf file

//#define nsubmenuMAX 10//Submenus max nbr
#define ntextMAX 100//Texts max nbr
#define npictureMAX 50//Pictures max nbr
#define nbuttonMAX 50//Buttons max nbr
#define nformMAX 20//Forms max nbr
#define ncheckboxMAX 20//Checkboxs max nbr
#define nprogressbarMAX 10//Progress bars max nbr
#define ntrackbarMAX 20//Track bars max nbr
#define npageMAX 10//Pages max nbr

#define TEXT_TYPE 1
#define PICTURE_TYPE 2
#define BUTTON_TYPE 3
#define FORM_TYPE 4
#define CHECKBOX_TYPE 5
#define PROGRESSBAR_TYPE 6
#define TRACKBAR_TYPE 7

//Surface globales
SDL_Surface* DLL_EXPORT screen;//window surface
PICTURE* DLL_EXPORT bg;//background picture Surface
SDL_Surface* DLL_EXPORT status;//status bar surface

//positions
SDL_Rect DLL_EXPORT POSstatus;

//variables globales
char DLL_EXPORT chaine[100];
char DLL_EXPORT windowTitle[100];
bool DLL_EXPORT design_mode;
//bool changedMouse;

/*************************************************************************/
/**Infos interactivit**/

TEXT* DLL_EXPORT text[ntextMAX];//Text
int DLL_EXPORT nTexts;
int DLL_EXPORT begT, DLL_EXPORT endT;
PICTURE* DLL_EXPORT picture[npictureMAX];//Picture
int DLL_EXPORT nPictures;
int DLL_EXPORT begP, DLL_EXPORT endP;
BUTTON* DLL_EXPORT button[nbuttonMAX];//Button
int DLL_EXPORT nButtons, DLL_EXPORT activ_button;
int DLL_EXPORT begB, DLL_EXPORT endB;
FORM* DLL_EXPORT form[nformMAX];//Form
int DLL_EXPORT nForms, DLL_EXPORT activ_form;
int DLL_EXPORT begF, DLL_EXPORT endF;
CHECKBOX* DLL_EXPORT checkbox[ncheckboxMAX];//Checkbox
int DLL_EXPORT nCheckbox;
int DLL_EXPORT begCB, DLL_EXPORT endCB;
PROGRESSBAR* DLL_EXPORT progressbar[nprogressbarMAX];//Progress bar
int DLL_EXPORT nProgressbar;
int DLL_EXPORT begPB, DLL_EXPORT endPB;
TRACKBAR* DLL_EXPORT trackbar[ntrackbarMAX];//Track bar
int DLL_EXPORT nTrackbar;
int DLL_EXPORT begTB, DLL_EXPORT endTB;

PAGE* DLL_EXPORT page[npageMAX];//Page
int DLL_EXPORT nPages, DLL_EXPORT activ_page;

/*************************************************************************/
/**Prototypes**/

/*GMLib.c*/
void DLL_EXPORT GMLib_Init();
void DLL_EXPORT GM_startDesignMode();
void DLL_EXPORT GM_stopDesignMode();
SDL_Event DLL_EXPORT GM_get();
void DLL_EXPORT GM_designMode();

/*window.c*/
void DLL_EXPORT GM_createWindow (char title[], int w, int h, int R, int G, int B);
void DLL_EXPORT GM_fullscreen(bool activate);
void DLL_EXPORT GM_freeSurface (SDL_Surface* S);
SDL_Surface* DLL_EXPORT GM_drawRect (SDL_Surface * dst, int x, int y, int w, int h, int R, int G, int B);
void DLL_EXPORT GM_put (SDL_Surface* dst, SDL_Surface* bloc, int x, int y, bool flip);
void DLL_EXPORT GM_putPart (SDL_Surface* dst, SDL_Surface* bloc, int x, int y, int xp, int yp, int w, int h);
void DLL_EXPORT GM_winTitle ( char title[]);
void DLL_EXPORT GM_winIcon ( char file[]);
void DLL_EXPORT GM_animate (int x, int y, int nbr, char dossier[], int fps);
void DLL_EXPORT GM_displayRefresh(bool flip);
void DLL_EXPORT GM_backgroundLoad(char file[], DISPLAY parameter);
void DLL_EXPORT GM_bgRedraw(int x, int y, int w, int h);

/*page.c*/
PAGE* DLL_EXPORT GM_createPage(int id);
void DLL_EXPORT GM_setActivPage(int id);
void DLL_EXPORT GM_displayFullPage(int id);
int DLL_EXPORT GM_getActivPage();

/*picture.c*/
PICTURE* DLL_EXPORT GM_createPicture(int x, int y, char file[], bool display);
void DLL_EXPORT GM_displayPicture(PICTURE* P, bool display);
void DLL_EXPORT GM_replacePicture(PICTURE* P, int x, int y, bool flip);
void DLL_EXPORT GM_alpha (SDL_Surface** image, int opacite);
SDL_Surface* DLL_EXPORT GM_pictureLoad(char file[]);
void DLL_EXPORT GM_duplicatePicture(PICTURE* P, int x, int y, int w, int h, DISPLAY parameter);

/*text.c*/
TEXT* DLL_EXPORT GM_createText(int x, int y, char string[], int size, int R, int G, int B, bool display);
void DLL_EXPORT GM_createTmpText(int x, int y, char string[], int size, int R, int G, int B);
SDL_Surface* DLL_EXPORT GM_text(char chaine[], int size, int R, int G, int B);
void DLL_EXPORT GM_displayText(TEXT* T, bool display);
void DLL_EXPORT GM_replaceText(TEXT* T, int x, int y, bool flip);
void DLL_EXPORT GM_modifyText(TEXT* T, char newText[]);

/*input.c*/
void DLL_EXPORT GM_strcut(char chaine[], int x, int n, char dst[]);
void DLL_EXPORT GM_afficherInfo(char chaine[]);
void DLL_EXPORT GM_afficherInfoRGB(char chaine[], int R, int G, int B);
void DLL_EXPORT GM_effacerInfo();
int DLL_EXPORT GM_txtInput(FORM* txtForm, char str[], int size, int max, int mode);
int DLL_EXPORT GM_stringtotable(char chaine[], int T[]);
void DLL_EXPORT GM_FormRefresh(SDL_Surface* bloc, FORM *F, int w, int h);

/*mouse.c*/
MOUSE* DLL_EXPORT GM_createMouse(char file[], int x, int y);
void DLL_EXPORT GM_changeMouse(MOUSE *Cur);
int DLL_EXPORT GM_mouseIn(int x, int y, int w, int h);
int DLL_EXPORT GM_mouseX();
int GM_mouseY();

/*form.c*/
FORM* DLL_EXPORT GM_createForm(int x, int y, char folder[], bool display);
void DLL_EXPORT GM_displayForm(FORM* F, bool display);
void DLL_EXPORT GM_replaceForm(FORM* F, int x, int y, bool flip);

/*button.c*/
BUTTON* DLL_EXPORT GM_createButton(int x, int y, char file[], char file_over[], char file_clic[], bool display);
void DLL_EXPORT GM_displayButton(BUTTON* B, bool display);
void DLL_EXPORT GM_replaceButton(BUTTON* B, int x, int y, bool flip);
void DLL_EXPORT GM_Text_on_Button(BUTTON* B, TEXT* button, TEXT* over, TEXT* clic);

/*checkbox.c*/
CHECKBOX* DLL_EXPORT GM_createCheckBox(int x, int y, char folder[], bool checked, bool display);
void DLL_EXPORT GM_displayCB(CHECKBOX* CB, bool display);
void DLL_EXPORT GM_replaceCB(CHECKBOX* CB, int x, int y, bool flip);
void DLL_EXPORT GM_Text_on_Checkbox(CHECKBOX* CB, TEXT* on, TEXT* off, SIDE side);//not coded*

/*progressbar.c*/
PROGRESSBAR* DLL_EXPORT GM_createProgressBar(int x, int y, char empty[], char full[], bool display);
void DLL_EXPORT GM_displayPB(PROGRESSBAR* PB, bool display);
void DLL_EXPORT GM_replacePB(PROGRESSBAR* PB, int x, int y, bool flip);
void DLL_EXPORT GM_modifyPB(PROGRESSBAR* PB, float percent);
void DLL_EXPORT GM_initPB(PROGRESSBAR* PB);
void DLL_EXPORT GM_setPB(PROGRESSBAR* PB, SIDE from, bool txtdisplay);

/*trackbar*/
TRACKBAR* DLL_EXPORT GM_createTrackBar(int x, int y, int size, char tracker[], char tracker_over[], bool display);
void DLL_EXPORT GM_displayTB(TRACKBAR* TB, bool display);
void DLL_EXPORT GM_replaceTB(TRACKBAR* TB, int x, int y, bool flip);
void DLL_EXPORT GM_modifyTB(TRACKBAR* TB, float value);
void DLL_EXPORT GM_initTB(TRACKBAR* TB);
float DLL_EXPORT GM_getValTB(TRACKBAR* TB);
void DLL_EXPORT GM_setTB(TRACKBAR* TB, float min, float max, SIDE from);

#endif
